Documentation
¶
Overview ¶
Package "issue258" provides primitives to interact with the AsyncAPI specification.
Code generated by github.com/lerenn/asyncapi-codegen version (devel) DO NOT EDIT.
Index ¶
Constants ¶
const AsyncAPIVersion = "1.0.0"
AsyncAPIVersion is the version of the used AsyncAPI document
const (
// TestPath is the constant representing the 'Test' channel path.
TestPath = "test"
)
Variables ¶
var ChannelsPaths = []string{ TestPath, }
ChannelsPaths is an array of all channels paths
Functions ¶
This section is empty.
Types ¶
type IntValueSchema ¶
type IntValueSchema struct {
Value *int64 `json:"value,omitempty"`
}
IntValueSchema is a schema from the AsyncAPI specification required in messages
type MessageWithCorrelationID ¶
MessageWithCorrelationID is implemented by messages that carry a correlation ID.
type StrValueSchema ¶
type StrValueSchema struct {
Value *string `json:"value,omitempty"`
}
StrValueSchema is a schema from the AsyncAPI specification required in messages
type TestMessageMessage ¶
type TestMessageMessage struct {
// Payload will be inserted in the message payload
Payload TestMessageMessagePayload
}
TestMessageMessage is the message expected for 'TestMessageMessage' channel.
func NewTestMessageMessage ¶
func NewTestMessageMessage() TestMessageMessage
NewTestMessageMessage creates a new TestMessageMessage with default values if any.
type TestMessageMessagePayload ¶
type TestMessageMessagePayload struct {
// WARNING: only one of the following fields must be set
IntValueSchema *IntValueSchema `json:"-"`
StrValueSchema *StrValueSchema `json:"-"`
}
TestMessageMessagePayload is a schema from the AsyncAPI specification required in messages
func (TestMessageMessagePayload) MarshalJSON ¶
func (t TestMessageMessagePayload) MarshalJSON() ([]byte, error)
MarshalJSON marshals the oneOf schema, emitting the single member that is set.
func (*TestMessageMessagePayload) UnmarshalJSON ¶
func (t *TestMessageMessagePayload) UnmarshalJSON(data []byte) error
UnmarshalJSON unmarshals JSON into the first oneOf member that accepts it. Without a discriminator, members are tried in order; the first one that unmarshals without error wins.